@@ -7,9 +7,10 @@
 #'  object.  
 #' @return A matrix of conditional genetic distance estimates.
 #' @author Rodney J. Dyer \email{rjdyer@@vcu.edu}
+#' @importFrom popgraph popgraph
 #' @export
 dist_cgd <- function( x, stratum="Population" ) {
-  require(popgraph)
+  #require(popgraph)
   
   if( !is( x, "data.frame") )
     stop("You need to pass a data.frame to dist_cavalli() to work.")
@@ -19,8 +20,8 @@ dist_cgd <- function( x, stratum="Population" ) {
 
 
   mv <- to_mv( x )
-  graph <- popgraph:::population_graph(x=mv, groups=factor( as.character( x[[stratum]] )))
-  ret <- popgraph:::to_matrix(graph, mode = "shortest path")
+  graph <- popgraph::popgraph(x=mv, groups=factor( as.character( x[[stratum]] )))
+  ret <- popgraph::to_matrix(graph, mode = "shortest path")
   return(ret)
 }
 
