@@ -4,6 +4,7 @@
 #'  a set of them if the value passed is a \code{data.frame} with locus objects.
 #'  
 #' @param x Either a \code{locus} object or a data.frame with locus objects.
+#' @param small.sample.correction Passes this along to He for small sample sizes.
 #' @return The inbreeding F statistic as a \code{numeric} value or a \code{data.frame}
 #'  if you passed multiple loci to this function.
 #' @export
@@ -11,9 +12,9 @@
 #' @examples
 #' loci <- c( locus( c("A","A") ), locus( c("A","A") ), locus( c("A","B") ) )
 #' Fis( loci )
-Fis <- function( x ) {
+Fis <- function( x, small.sample.correction=FALSE ) {
   if( is(x,"locus") ) {
-    ret <- 1.0 - Ho(x) / He(x)
+    ret <- 1.0 - Ho(x) / He(x, small.sample.correction)
     names(ret) <- "Fis"
   }
   else if( is(x,"data.frame")) {
@@ -21,8 +22,6 @@ Fis <- function( x ) {
     ret <- data.frame( Locus=cols, Fis=0)
     for( i in 1:length(cols) )
       ret$Fis[i] <- Fis( x[[cols[i]]] )
-    
-   
   }
   else
     stop(paste("This function does not know how to handle data of type",class(x)))
